# Django Groove

django-groove is a Django app shipping with various utilities, such as a 
template context processor that adds the current Django Site object and a 
utility method for sending HTML mail.

This is an early draft and work in progress.


## Installation

Install `django-groove` (available on PyPi):

	pip install django-groove

